pub struct StartTaskTemplate {
pub task_name: String,
pub desc: Option<String>,
pub group: Option<String>,
pub prefix: Option<String>,
pub msg: Option<String>,
pub estimated_duration: Option<String>,
pub language: LanguageCode,
}Expand description
Card template for notifying that a job or task has started.
Generates a wathet (light blue) header card with the task name, start time, optional description/duration, running status, and optionally a storage column pair and collapsible running-overview panel.
Fields
task_name: Stringdesc: Option<String>group: Option<String>prefix: Option<String>msg: Option<String>estimated_duration: Option<String>language: LanguageCodeTrait Implementations
Sourceimpl LarkTemplate for StartTaskTemplate
impl LarkTemplate for StartTaskTemplate
Sourcefn generate(&self) -> CardContent
fn generate(&self) -> CardContent
CardContent (a serde_json::Value).Auto Trait Implementations
impl Freeze for StartTaskTemplate
impl RefUnwindSafe for StartTaskTemplate
impl Send for StartTaskTemplate
impl Sync for StartTaskTemplate
impl Unpin for StartTaskTemplate
impl UnsafeUnpin for StartTaskTemplate
impl UnwindSafe for StartTaskTemplate