Module workflow

Module workflow 

Structs

TaskSetProgress
Progress counters for a single task set, used by task_set_progress.

Functions

comparison_complete
config_upload_complete
create_custom_template
job_complete
job_submission_complete
job_submission_failure
job_submission_start
network_submission_complete
network_submission_failure
network_submission_start
result_collection_complete
result_collection_start
task_set_progress
NOTE: The header is always blue. overall_status is used only as the header tag label (not for color detection), allowing callers to pass a descriptive string like “3/5 complete” for display purposes.