task_set_progress

Function task_set_progress 

pub fn task_set_progress(
    progress: &HashMap<&str, TaskSetProgress>,
    overall_status: &str,
    language: LanguageCode,
) -> GenericCardTemplate
NOTE: The header is always blue. overall_status is used only as the header tag label (not for color detection), allowing callers to pass a descriptive string like “3/5 complete” for display purposes.